summaryrefslogtreecommitdiff
path: root/epan/dissectors/packet-3g-a11.c
diff options
context:
space:
mode:
authorBill Meier <wmeier@newsguy.com>2008-12-17 17:23:37 +0000
committerBill Meier <wmeier@newsguy.com>2008-12-17 17:23:37 +0000
commita8f30cbca1b3c7831be55ba0f68e9207ae9704f4 (patch)
treed506f25dfc17f3054d84127c2731ad8db790ae2b /epan/dissectors/packet-3g-a11.c
parent27808f5b828c45f98e7f38c522b4ace967a69a24 (diff)
downloadwireshark-a8f30cbca1b3c7831be55ba0f68e9207ae9704f4.tar.gz
Fix some typos and spelling (mostly in text strings)
svn path=/trunk/; revision=27037
Diffstat (limited to 'epan/dissectors/packet-3g-a11.c')
-rw-r--r--epan/dissectors/packet-3g-a11.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/epan/dissectors/packet-3g-a11.c b/epan/dissectors/packet-3g-a11.c
index d3176665e8..0ab500892e 100644
--- a/epan/dissectors/packet-3g-a11.c
+++ b/epan/dissectors/packet-3g-a11.c
@@ -100,7 +100,7 @@ static int hf_a11_ase_gre_proto_type = -1;
static int hf_a11_ase_gre_key = -1;
static int hf_a11_ase_pcf_addr_key = -1;
/* Foward QoS Information */
static int hf_a11_fqi_length = -1;
static int hf_a11_fqi_srid = -1;
static int hf_a11_fqi_flags = -1;
@@ -2007,14 +2007,14 @@ proto_register_a11(void)
"Reverse QoS Update Flow Count.", HFILL }
},
{ &hf_a11_fqui_updated_qoslen,
- { "Foward Updated QoS Sub-Blob Length", "a11.ext.fqui.updatedqoslen",
+ { "Forward Updated QoS Sub-Blob Length", "a11.ext.fqui.updatedqoslen",
FT_UINT8, BASE_DEC, NULL, 0,
- "Foward Updated QoS Sub-Blob Length.", HFILL }
+ "Forward Updated QoS Sub-Blob Length.", HFILL }
},
{ &hf_a11_fqui_updated_qos,
- { "Foward Updated QoS Sub-Blob", "a11.ext.fqui.updatedqos",
+ { "Forward Updated QoS Sub-Blob", "a11.ext.fqui.updatedqos",
FT_BYTES, BASE_NONE, NULL, 0,
- "Foward Updated QoS Sub-Blob.", HFILL }
+ "Forward Updated QoS Sub-Blob.", HFILL }
},
{ &hf_a11_rqui_updated_qoslen,
{ "Reverse Updated QoS Sub-Blob Length", "a11.ext.rqui.updatedqoslen",
@@ -100,7 +100,7 @@ static int hf_a11_ase_gre_proto_type = -1;
static int hf_a11_ase_gre_key = -1;
static int hf_a11_ase_pcf_addr_key = -1;
-/* Foward QoS Information */
+/* Forward QoS Information */
static int hf_a11_fqi_length = -1;
static int hf_a11_fqi_srid = -1;